@@ -46,6 +46,30 @@ def deal_with_draw_box(args):
     draw_box_on_img(src_file, dst_file, bbox_list)
 
 
+def deal_width_draw_one_color(args):
+    """显示单一色值的图像"""
+    if args.src_file is None:
+        print("must specify parameter : src_file")
+        return
+    if args.dst_file is None:
+        print("must specify parameter : dst_file")
+        return
+    if args.color is None:
+        print("must specify parameter : color")
+        return
+    start_color, end_color = None, None
+    if '-' not in args.color:
+        start_color = int(args.color)
+        end_color = int(args.color)
+    else:
+        start, end = args.color.strip().split('-')
+        start_color = int(start)
+        end_color = int(end)
+    img = cv2.imread(args.src_file, cv2.IMREAD_GRAYSCALE)
+    img = cv2.inRange(img, start_color, end_color)
+    cv2.imwrite(args.dst_file, img)
+    
+
 def calc_iou(box1, box2):
     """
     :param box1: = [xmin1, ymin1, xmax1, ymax1]
@@ -84,16 +108,19 @@ def deal_with_calc_iou(box):
 def main():
     """主处理函数"""
     parser = argparse.ArgumentParser(description="many tools easily to use for computer vision")
-    parser.add_argument('tool_name', type=str, help='tool names : draw_box, calc_iou')
+    parser.add_argument('tool_name', type=str, help='tool names : draw_box, calc_iou, draw_one_color')
     parser.add_argument('-s', '--src_file', type=str, help='source file of image')
     parser.add_argument('-d', '--dst_file', type=str, help='destination file of image')
     parser.add_argument('-b', '--box', type=str, help='box info e.g. 100,100,200,200_300,300,400,400 for x1x2y1y2 format and 100,100,200,200-300,300,400,400 for xywh format')
+    parser.add_argument('-c', '--color', type=str, help='color value of gray image e.g. 138-142')
     args = parser.parse_args()
     tool_name = args.tool_name
     if tool_name == 'draw_box':
         deal_with_draw_box(args)
     elif tool_name == 'calc_iou':
         deal_with_calc_iou(args.box)
+    elif tool_name == 'draw_one_color':
+        deal_width_draw_one_color(args)
     else:
         print(f"{tool_name} has not supported ~")
 
